@@ -2,7 +2,7 @@ from singer_sdk import typing as th
 
 schema = th.PropertiesList(
     th.Property("id", th.StringType),
-    th.Property("started_at", th.StringType),
+    th.Property("started_at", th.DateTimeType),
     th.Property("userId", th.StringType),
     th.Property("projectId", th.StringType),
     th.Property("taskId", th.StringType),
@@ -12,9 +12,12 @@ schema = th.PropertiesList(
     th.Property("isLocked", th.BooleanType),
     th.Property("customFieldValues", th.ArrayType(th.StringType)),
     th.Property("tagIds", th.ArrayType(th.StringType)),
-    th.Property("timeInterval", th.ObjectType(
-        th.Property("duration", th.StringType),
-        th.Property("end", th.StringType),
-        th.Property("start", th.StringType),
-    )),
+    th.Property(
+        "timeInterval",
+        th.ObjectType(
+            th.Property("duration", th.StringType),
+            th.Property("end", th.StringType),
+            th.Property("start", th.StringType),
+        ),
+    ),
 ).to_dict()
